import { DebugUtil } from "../TmFv3DApp/tmdet-extension/debug-utils";
import { loadWithUNITMPMembraneRepresentation } from "../TmFv3DApp/UniTmpHelper";
import * as React from "react";
import { TmViewer } from "./tmdet-viewer/TmViewer";
import { ViewerProps } from "@rcsb/rcsb-molstar/build/src/viewer";
import { TMDETMembraneOrientation } from "../TmFv3DApp/tmdet-extension/behavior";
import { PluginSpec } from "molstar/lib/mol-plugin/spec";
import { PluginLayoutControlsDisplay } from "molstar/lib/mol-plugin/layout";
import { PluginConfig } from "molstar/lib/mol-plugin/config";
import { PluginContext } from "molstar/lib/mol-plugin/context";

// customElements.define(TmFv1DElement.TagName, TmFv1DElement);

const Extensions = {
    'tmdet-membrane-orientation': PluginSpec.Behavior(TMDETMembraneOrientation)
};

const viewerParams: Partial<ViewerProps> = {
        layoutIsExpanded: true,
        layoutShowControls: true,
        layoutControlsDisplay: 'reactive' as PluginLayoutControlsDisplay,
        layoutShowSequence: true,
        layoutShowLog: true,

        viewportShowExpand: PluginConfig.Viewport.ShowExpand.defaultValue,
        viewportShowSelectionMode: PluginConfig.Viewport.ShowSelectionMode.defaultValue,
        volumeStreamingServer: PluginConfig.VolumeStreaming.DefaultServer.defaultValue,

};

function createTmdetViewer(elementId: string, configParams: any,
    callBack: (ctx:PluginContext) => {},
    deferred: boolean,
    viewerProps: Partial<ViewerProps> = viewerParams) {

    if (deferred) {
        document.addEventListener("DOMContentLoaded", (event) => {
            console.log('DOMContentLoaded', deferred);
            (async function(event) {

                DebugUtil.enableLog();
                const viewer = new TmViewer(elementId, {
                    ...viewerProps,
                    layoutShowControls:false,
                    layoutShowSequence: true,
                    showWelcomeToast: false,
                    canvas3d: {
                        multiSample: {
                            mode: 'off'
                        }
                    }
                });
                await loadWithUNITMPMembraneRepresentation(viewer, configParams);
                if (callBack) {
                    callBack(viewer.plugin);
                }
            })();
        });
    } else {
        DebugUtil.enableLog();
        const viewer = new TmViewer(elementId, {
            ...viewerProps,
            layoutShowControls:false,
            layoutShowSequence: true,
            showWelcomeToast: false,
            canvas3d: {
                multiSample: {
                    mode: 'off'
                }
            }
        });
        loadWithUNITMPMembraneRepresentation(viewer, configParams);
        if (callBack) {
            callBack(viewer.plugin);
        }
        return viewer;
    }
}

export {
    createTmdetViewer,
    DebugUtil
};
